================
API Introduction
================

Aydin API generally follow from upstream APIs. Aydin provides a multi-layer API
with varying levels of configurability and functionality, which is built on top
of the packages we use for computation and other purposes.


#. `Restoration <restoration.html>`_
#. `Image Translator <image_translator.html>`_
#. `Transforms <transforms.html>`_
#. `Feature Generator <feature_generator.html>`_
#. `Regressors <regressors.html>`_
#. `IO <io.html>`_
#. `NN <nn.html>`_



